#ifndef CHATLOGINDIALOG_H
#define CHATLOGINDIALOG_H

#include <QDialog>
#include <QSettings>

namespace Ui {
    class ChatLoginDialog;
}

class ChatLoginDialog : public QDialog
{
    Q_OBJECT

signals:
    void login(QString username, QString password, bool save);

public:
    explicit ChatLoginDialog(QWidget *parent = 0);
    ~ChatLoginDialog();

private:
    Ui::ChatLoginDialog *ui;

private slots:
    void accept();
};

#endif // CHATLOGINDIALOG_H
